rootProject.name = "mahjong-utils"

includeBuild("build-scripts")
include(":mahjong-utils-entry")
